@@ -22,7 +22,9 @@ class DoManager(object):
         json = self.request('/droplets/')
         return json['droplets']
 
-    def new_droplet(self, name, size_id, image_id, region_id, ssh_key_ids=None, virtio=False, private_networking=False):
+    def new_droplet(self, name, size_id, image_id, region_id,
+            ssh_key_ids=None, virtio=False, private_networking=False,
+            backups_enabled=False):
         params = {
                 'name': name,
                 'size_id': size_id,
@@ -30,6 +32,7 @@ class DoManager(object):
                 'region_id': region_id,
                 'virtio': virtio,
                 'private_networking': private_networking,
+                'backups_enabled': backups_enabled,
             }
         if ssh_key_ids:
             params['ssh_key_ids'] = ssh_key_ids
@@ -110,8 +113,8 @@ class DoManager(object):
         json.pop('status', None)
         return json
 
-    def destroy_droplet(self, id, scrub_data=False):
-        params = {'scrub_data': scrub_data}
+    def destroy_droplet(self, id, scrub_data=True):
+        params = {'scrub_data': '1' if scrub_data else '0'}
         json = self.request('/droplets/%s/destroy/' % id, params)
         json.pop('status', None)
         return json
